@@ -137,17 +137,18 @@ class Render:
             raise Exception("Local file does not exists")
 
         max_cmd = Path(os.environ['ADSK_3DSMAX_x64_2018']) / '3dsmaxcmd'
-        process = Popen([
+        args = [
             str(max_cmd),
             "-continueOnError",
             "-batchRender",
             f'-outputName:{str(self.scene.workdir / f"0.{extension}")}',
-            str(self.scene.localfile)],
-            stderr=STDOUT,
-            stdout=PIPE,
-            bufsize=1,
-        )
+        ]
+        if self.texture:
+            args.append(f'-bitmapPath:{self.texture.localfile}')
+        args.append(str(self.scene.localfile))
+        logger.debug(f"Params = {args}")
 
+        process = Popen(args, stderr=STDOUT, stdout=PIPE, bufsize=1)
         follow = FollowLog(self.scene.workdir, extension)
         for file in follow.iterate_files(process.stdout):
             view = file.parent.name
