@@ -1,12 +1,12 @@
-import os
+from render.util import user_data
 
 broker_url = (
     'amqp://'
-    f'{os.environ["RABBITMQ_DEFAULT_USER"]}'
-    f':{os.environ["RABBITMQ_DEFAULT_PASS"]}'
-    f'@{os.environ["RABBITMQ_HOST"]}'
-    f':{os.environ.get("RABBITMQ_PORT", "5672")}'
-    f'/{os.environ["RABBITMQ_DEFAULT_VHOST"]}'
+    f'{user_data["rabbit_user"]}'
+    f':{user_data["rabbit_pass"]}'
+    f'@{user_data["rabbitmq_host"]}'
+    f':{user_data.get("rabbit_port", "5672")}'
+    f'/{user_data["rabbit_vhost"]}'
 )
 
 task_routes = {
