@@ -37,5 +37,5 @@ def main(args):
 if __name__ == '__main__':
     parser = ArgumentParser()
     parser.add_argument("window_name")
-    parser.add_argument("delay", type=int, default=60)
+    parser.add_argument("--delay", type=int, default=60)
     main(parser.parse_args())
